var assert = require("assert");
var jsonSan = require(__dirname + "/../lib/json-san");

var validJson = '[ "foo" ]';
var invalidJson = "[ 'foo' ]";
var reallyInvalidJson = '[ "foo\' ]';

exports["Parser works as expected for valid input, syncronously"] = function (test) {
    var result = jsonSan.parse(validJson);
    test.ok(Array.isArray(result));
    test.equal(result.length, 1);
    test.equal(result[0], "foo");
    test.done();
};

exports["Parser works as expected for valid input, asyncronously"] = function (test) {
    jsonSan.parse(validJson, function (err, result) {
        test.equal(null, err);
        test.ok(Array.isArray(result));
        test.equal(result.length, 1);
        test.equal(result[0], "foo");
        test.done();
    })
};

exports["Parser returns error on invalid input, syncronously"] = function (test) {
    try {
      jsonSan.parse(invalidJson);
    } catch (e) {
      test.ok(e);
      test.done();
    }
};

exports["Parser returns error on invalid input, asyncronously"] = function (test) {
    jsonSan.parse(invalidJson, function (err) {
        test.ok(err);
        test.done();
    });
};

exports["Stringifyer works as expected, syncronously"] = function (test) {
    test.equal(jsonSan.stringify([ "foo" ]),
               "[\"foo\"]");
    test.done();
};

exports["Stringifyer works as expected, asyncronously"] = function (test) {
    jsonSan.stringify([ "foo" ], function (err, result) {
        test.done();
    });
};
